@@ -193,8 +193,22 @@ RDO_PKG_MAP = [
     SingleRule('m2crypto', 'm2crypto'),
     SingleRule('libvirt-python', 'libvirt-python', py3pkg='libvirt-python3'),
     SingleRule('tempest-horizon', 'python-horizon-tests-tempest'),
+    # simple direct mapping no name change
     MultiRule(
         mods=['PyYAML', 'numpy', 'pyflakes', 'pylint', 'pyparsing',
+              'dib-utils',
+              'diskimage-builder',
+              'graphviz',
+              'instack-undercloud',
+              'os-apply-config',
+              'os-collect-config',
+              'os-net-config',
+              'os-refresh-config',
+              'pexpect',
+              'protobuf',
+              'sympy',
+              'systemd-python',
+              'watchdog',
               'pystache', 'pytz', 'pysendfile'],
         pkgfun=lambda mod: ((mod, mod, 'python3-' + mod))),
     # OpenStack services
@@ -209,7 +223,8 @@ RDO_PKG_MAP = [
               'monasca-notification', 'monasca-persister', 'monasca-transform',
               'murano', 'neutron', 'neutron-fwaas', 'neutron-lbaas',
               'neutron-vpnaas', 'nova', 'octavia', 'rally', 'sahara', 'swift',
-              'Tempest', 'trove', 'tuskar', 'vitrage', 'zaqar'],
+              'Tempest', 'tripleo-common', 'trove', 'tuskar', 'vitrage',
+              'zaqar'],
         pkgfun=openstack_prefix_tr),
     # Horizon plugins (normalized to openstack-<project>-ui)
     RegexRule(pattern=r'\w+-(dashboard|ui)', pkgfun=rdo_horizon_plugins_tr),
