@@ -34,25 +34,28 @@ class Pymod2PkgTests(unittest.TestCase):
 
     def test_default_translation_suse(self):
         self.assertEqual(pymod2pkg.module2package('oslo.db', 'suse'),
-                         'python2-oslo.db')
+                         'python-oslo.db')
         self.assertEqual(pymod2pkg.module2package('Babel', 'suse'),
-                         'python2-Babel')
+                         'python-Babel')
+        self.assertEqual(pymod2pkg.module2package(
+            'Babel', 'suse', py_vers=['py', 'py2', 'py3']),
+                         ['python-Babel', 'python2-Babel', 'python3-Babel'])
 
     def test_translation_suse(self):
         self.assertEqual(pymod2pkg.module2package('nova', 'suse'),
                          'openstack-nova')
         self.assertEqual(pymod2pkg.module2package('aodhclient',
                                                   'suse'),
-                         'python2-aodhclient')
+                         'python-aodhclient')
         self.assertEqual(pymod2pkg.module2package('gnocciclient',
                                                   'suse'),
-                         'python2-gnocciclient')
+                         'python-gnocciclient')
         self.assertEqual(pymod2pkg.module2package('python-cinderclient',
                                                   'suse'),
-                         'python2-cinderclient')
+                         'python-cinderclient')
         self.assertEqual(pymod2pkg.module2package('python-neutronclient',
                                                   'suse'),
-                         'python2-neutronclient')
+                         'python-neutronclient')
         self.assertEqual(pymod2pkg.module2package('Tempest', 'suse'),
                          'openstack-tempest')
 
@@ -109,8 +112,8 @@ class Pymod2PkgTests(unittest.TestCase):
 
     def test_translation_py2py3_suse(self):
         self.assertEqual(pymod2pkg.module2package('nova', 'suse',
-                         py_vers=['py2', 'py3']),
-                         ['openstack-nova', ''])
+                         py_vers=['py', 'py2', 'py3']),
+                         ['openstack-nova', '', ''])
         self.assertEqual(pymod2pkg.module2package('aodhclient',
                          'suse', py_vers=['py2', 'py3']),
                          ['python2-aodhclient', 'python3-aodhclient'])
@@ -126,8 +129,11 @@ class Pymod2PkgTests(unittest.TestCase):
                          py_vers=['py2', 'py3']),
                          ['python2-neutronclient', 'python3-neutronclient'])
         self.assertEqual(pymod2pkg.module2package('Tempest', 'suse',
+                         py_vers=['py', 'py2', 'py3']),
+                         ['openstack-tempest', '', ''])
+        self.assertEqual(pymod2pkg.module2package('devel', 'suse',
                          py_vers=['py2', 'py3']),
-                         ['openstack-tempest', ''])
+                         ['python-devel', 'python3-devel'])
 
     def test_translation_py2py3_ubuntu(self):
         self.assertEqual(pymod2pkg.module2package('nova', 'ubuntu',
@@ -144,13 +150,13 @@ class Pymod2PkgTests(unittest.TestCase):
     def test_default_translation_py2py3_rdo(self):
         self.assertEqual(pymod2pkg.module2package('oslo.db', 'fedora',
                          py_vers=['py2', 'py3']),
-                         ['python-oslo-db', 'python3-oslo-db'])
+                         ['python2-oslo-db', 'python3-oslo-db'])
         self.assertEqual(pymod2pkg.module2package('Babel', 'fedora',
                          py_vers=['py2', 'py3']),
                          ['python-babel', 'python3-babel'])
         self.assertEqual(pymod2pkg.module2package('nova', 'fedora',
-                         py_vers=['py2', 'py3']),
-                         ['openstack-nova', ''])
+                         py_vers=['py', 'py2', 'py3']),
+                         ['openstack-nova', '', ''])
 
 
 class RegexRuleTests(unittest.TestCase):
@@ -158,12 +164,13 @@ class RegexRuleTests(unittest.TestCase):
 
         def dummy_tr(mod):
             mod = mod.replace('dashboard', 'ui')
-            return "openstack-{}".format(mod), ''
+            return "openstack-{}".format(mod), '', ''
 
         rule = pymod2pkg.RegexRule(r'\w+-(dashboard|ui)', dummy_tr)
         self.assertEqual(rule('dummy-dashboard', 'rdo'),
-                         ('openstack-dummy-ui', ''))
-        self.assertEqual(rule('dummy-ui', 'rdo'), ('openstack-dummy-ui', ''))
+                         ('openstack-dummy-ui', '', ''))
+        self.assertEqual(rule('dummy-ui', 'rdo'),
+                         ('openstack-dummy-ui', '', ''))
 
 
 if __name__ == '__main__':
